Module borrow

Module borrow 

Structs

FlattenDeserializer
Facade Deserializer<'de> used to implement #[strede(flatten)] for the borrow family.
FlattenEntry
Entry handle produced by FlattenDeserializer.
FlattenMapAccess
MapAccess<'de> produced by FlattenEntry.

Traits

BytesAccess
Streams a byte string in zero-copy chunks. Obtained from Entry::deserialize_bytes_chunks.
Deserialize
Types that can deserialize themselves from a Deserializer stream.
Deserializer
A stream of tokens that can be decoded into Rust values.
Entry
Owned handle for one item slot, passed into the closure of Deserializer::entry.
FlattenCont
Continuation for FlattenMapAccess. Determines what happens after the outer and inner arm stacks are combined via StackConcat.
MapAccess
Iterates the key-value pairs of a map. Obtained from Entry::deserialize_map.
MapArmStack
Borrow-family counterpart to crate::MapArmStackOwned.
MapKeyClaim
Proof that a key was consumed. Converts into a value probe.
MapKeyProbe
A key probe for a single map key in the borrow family. Forkable for racing multiple arms.
MapValueClaim
Proof that a value was consumed. Advances to the next key or ends the map (borrow family).
MapValueProbe
A value probe that can deserialize a value or skip it (borrow family).
SeqAccess
Iterates the elements of a sequence. Obtained from Entry::deserialize_seq.
SeqEntry
Owned handle for one element in a sequence.
StrAccess
Streams a string in zero-copy chunks. Obtained from Entry::deserialize_str_chunks.

Type Aliases

KP
Shorthand for the key probe type reachable from a Deserializer.
VC
Shorthand for the value claim type reachable from a borrow key probe type.
VP
Shorthand for the value probe type reachable from a borrow key probe type.
VP2
Shorthand for the value probe type reachable directly from a Deserializer.