pub type VC<'de, KP> = <<<KP as MapKeyProbe<'de>>::KeyClaim as MapKeyClaim<'de>>::ValueProbe as MapValueProbe<'de>>::ValueClaim;Expand description
Shorthand for the value claim type reachable from a borrow key probe type.
pub type VC<'de, KP> = <<<KP as MapKeyProbe<'de>>::KeyClaim as MapKeyClaim<'de>>::ValueProbe as MapValueProbe<'de>>::ValueClaim;Shorthand for the value claim type reachable from a borrow key probe type.