pub type VC<KP> = <<<KP as MapKeyProbeOwned>::KeyClaim as MapKeyClaimOwned>::ValueProbe as MapValueProbeOwned>::ValueClaim;Expand description
Shorthand for the value claim type reachable from a key probe type.
pub type VC<KP> = <<<KP as MapKeyProbeOwned>::KeyClaim as MapKeyClaimOwned>::ValueProbe as MapValueProbeOwned>::ValueClaim;Shorthand for the value claim type reachable from a key probe type.