pub type VP<KP> = <<KP as MapKeyProbeOwned>::KeyClaim as MapKeyClaimOwned>::ValueProbe;Expand description
Shorthand for the value probe type reachable from a key probe type.
pub type VP<KP> = <<KP as MapKeyProbeOwned>::KeyClaim as MapKeyClaimOwned>::ValueProbe;Shorthand for the value probe type reachable from a key probe type.